Enum mio_serial::ErrorKind
[−]
[src]
pub enum ErrorKind {
NoDevice,
InvalidInput,
Unknown,
Io(ErrorKind),
}Categories of errors that can occur when interacting with serial ports.
This list is intended to grow over time and it is not recommended to exhaustively match against it.
Variants
NoDeviceThe device is not available.
This could indicate that the device is in use by another process or was disconnected while performing I/O.
InvalidInputA parameter was incorrect.
UnknownAn unknown error occurred.
Io(ErrorKind)An I/O error occurred.
The type of I/O error is determined by the inner io::ErrorKind.