Struct mio_serial::SerialPortSettings
[−]
[src]
pub struct SerialPortSettings {
pub baud_rate: BaudRate,
pub data_bits: DataBits,
pub flow_control: FlowControl,
pub parity: Parity,
pub stop_bits: StopBits,
pub timeout: Duration,
}A struct containing all serial port settings
Fields
baud_rate: BaudRate
The baud rate in symbols-per-second
data_bits: DataBits
Number of bits used to represent a character sent on the line
flow_control: FlowControl
The type of signalling to use for controlling data transfer
parity: Parity
The type of parity to use for error checking
stop_bits: StopBits
Number of bits to use to signal the end of a character
timeout: Duration
Amount of time to wait to receive data before timing out