Struct mio_serial::SerialStream
source · [−]pub struct SerialStream { /* private fields */ }Expand description
SerialStream
Implementations
sourceimpl SerialStream
impl SerialStream
sourcepub fn open(builder: &SerialPortBuilder) -> Result<Self>
pub fn open(builder: &SerialPortBuilder) -> Result<Self>
Open a nonblocking serial port from the provided builder
Example
use mio_serial::{SerialPortBuilder, SerialStream};
use std::path::Path;
let args = mio_serial::new("/dev/ttyUSB0", 9600);
let serial = SerialStream::open(&args).unwrap();sourcepub fn pair() -> Result<(Self, Self)>
pub fn pair() -> Result<(Self, Self)>
Create a pair of pseudo serial terminals
Returns
Two connected Serial objects: (master, slave)
Errors
Attempting any IO or parameter settings on the slave tty after the master tty is closed will return errors.
Examples
use mio_serial::SerialStream;
let (master, slave) = SerialStream::pair().unwrap();sourcepub fn set_exclusive(&mut self, exclusive: bool) -> Result<()>
pub fn set_exclusive(&mut self, exclusive: bool) -> Result<()>
Sets the exclusivity of the port
If a port is exclusive, then trying to open the same device path again will fail.
See the man pages for the tiocexcl and tiocnxcl ioctl’s for more details.
Errors
Iofor any error while setting exclusivity for the port.